@@ -1,5 +1,5 @@
 package Strehler::Dancer2::Plugin::Admin;
-$Strehler::Dancer2::Plugin::Admin::VERSION = '1.4.2';
+$Strehler::Dancer2::Plugin::Admin::VERSION = '1.5.0';
 use strict;
 use Dancer2::Plugin;
 use Strehler::Helpers;
@@ -51,6 +51,14 @@ on_plugin_import {
             my ($editor_menu, $admin_menu) = Strehler::Helpers::top_bars();
             $tokens->{'editor_menu'} = $editor_menu;
             $tokens->{'admin_menu'} = $admin_menu;
+            if($dsl->config->{'Strehler'}->{'dashboard_active'} && $dsl->config->{'Strehler'}->{'dashboard_active'} == 1)
+            {
+                $tokens->{'dashboard_active'} = 1;
+            }
+            else
+            {
+                $tokens->{'dashboard_active'} = 0;
+            }
         }));
     };
     
