@@ -1,6 +1,7 @@
 package Strehler::Element::Article;
-$Strehler::Element::Article::VERSION = '1.4.2';
+$Strehler::Element::Article::VERSION = '1.5.0';
 use strict;
+use Cwd 'abs_path';
 use Moo;
 use Dancer2 0.154000;
 use Dancer2::Plugin::DBIC;
@@ -8,6 +9,13 @@ use Dancer2::Plugin::DBIC;
 extends 'Strehler::Element';
 with 'Strehler::Element::Role::Slugged';
 
+
+my $module_file_path = __FILE__;
+my $root_path = abs_path($module_file_path);
+$root_path =~ s/Article\.pm//;
+my $form_path = $root_path . "../forms";
+my $views_path = $root_path . "../views";
+
 #Standard element implementation
 
 sub metaclass_data 
@@ -54,6 +62,28 @@ sub class
     return __PACKAGE__;
 }
 
+sub form
+{
+    return $form_path . '/admin/article.yml';
+}
+sub multilang_form
+{
+    return $form_path . '/admin/article_multilang.yml';
+}
+
+sub add_main_column_span
+{
+    my $self = shift;
+    return $self->_property('add_main_column_span', 9);
+}
+sub custom_snippet_add_position
+{
+    my $self = shift;
+    return $self->_property('custom_snippet_position', 'right');
+}
+
+
+
 #Main title redefined to fetch title from multilang attributes
 
 sub main_title
@@ -72,6 +102,15 @@ sub main_title
 
 }
 
+sub form_modifications
+{
+    my $self = shift;
+    my $form = shift;
+    my $default_language = config->{Strehler}->{default_language};
+    $form->constraint({ name => 'title_' . $default_language, type => 'Required' }); 
+    return $form;    
+}
+
 sub fields_list
 {
     my $self = shift;
@@ -124,6 +163,16 @@ sub image
     }
 }
 
+sub custom_add_snippet
+{
+    return '<div class="thumbnail"><img id="image_preview" src="/strehler/images/no-image.png" /></div>';
+}
+sub entity_js
+{
+    my $self = shift;
+    return $self->_property('entity_js', '/strehler/js/article.js');
+}
+
 =encoding utf8
 
 =head1 NAME
